@@ -1,11 +1,12 @@
 # $File: //depot/OurNet-BBS/BBS/MAPLE2/SessionGroup.pm $ $Author: autrijus $
-# $Revision: #8 $ $Change: 2456 $ $DateTime: 2001/11/28 12:16:45 $
+# $Revision: #9 $ $Change: 2853 $ $DateTime: 2002/01/12 19:16:25 $
 
 package OurNet::BBS::MAPLE2::SessionGroup;
 
 use strict;
 use fields qw/bbsroot shmkey maxsession chatport passwd shmid shm _ego _hash/;
 use constant IsWin32 => ($^O eq 'MSWin32');
+use constant SIGUSR2 => IsWin32 ? '' : 'USR2';
 
 use OurNet::BBS::Base (
     '%registered' => {},
@@ -43,10 +44,10 @@ sub message_handler {
         }
     }
 
-    $SIG{USR2} = \&message_handler unless IsWin32;
+    $SIG{+SIGUSR2} = \&message_handler;
 };
 
-$SIG{USR2} = \&message_handler unless IsWin32;
+$SIG{+SIGUSR2} = \&message_handler;
 
 sub _lock {}
 sub _unlock {}
