@@ -1,16 +1,19 @@
 # $File: //depot/OurNet-BBS/BBS/MELIX/BBS.pm $ $Author: autrijus $
-# $Revision: #5 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $
+# $Revision: #7 $ $Change: 2440 $ $DateTime: 2001/11/27 15:38:54 $
 
 package OurNet::BBS::MELIX::BBS;
 
 use strict;
 use base qw/OurNet::BBS/;
 use fields qw/backend bbsroot brdshmkey maxboard sessionshmkey maxsession
-              usershmkey maxuser chatport passwd _ego _hash/;
+              chatport passwd _ego _hash/;
 use subs qw/readok writeok/;
-use OurNet::BBS::Base;
 
-sub writeok { 1 }
+use OurNet::BBS::Base (
+    '@USERS' => [qw/bbsroot/],
+);
+
+sub writeok { 0 }
 
 sub readok {
     my ($self, $user) = @_;
